---
gitea: none
include_toc: true
---
# dictionaries/rougail/01-base.yml

```yaml
---
version: '1.1'
var1:
  redefine: true
  exists: true
  default: yes
var2:
  description: a second variable
  redefine: true
  exists: true
  default: yes
```
# dictionaries/rougail/00-base.yml

```yaml
---
version: '1.1'
var1:
  description: a first variable
  hidden: true
  default: no
  mandatory: false
```
